@@ -853,7 +853,9 @@ func setupCmdExec(t *testing.T) (execFunc, *MockAPI, *MockWriter, *MockWriter, *
 		func() error { return nil },
 		func(*gitlab.Client, any) API { return mockAPI },
 		func(_ Cmd, _, _, _ string) KubectlWrapper { return mockKubectlWrapper },
-		func(_ Cmd, _, _, _, _, _, _, _, _, _, _, _, _ string) FluxWrapper { return mockFluxWrapper },
+		func(_ Cmd, _, _, _, _, _, _, _, _, _ string, _, _ []string, _, _, _ string) FluxWrapper {
+			return mockFluxWrapper
+		},
 		func(_, _ io.Writer, _ []string) Cmd { return mockCmd },
 	)
 
